# coding: utf-8


"""
IGNORE:
    Nutanix Flow Management APIs

    Manage Network Security Policy configuration of Nutanix clusters.  # noqa: E501

    OpenAPI spec version: 4.2.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
from ntnx_microseg_py_client.models.microseg.v4.config.SecurityPolicyState import SecurityPolicyState  # noqa: F401,E501
from ntnx_microseg_py_client.models.microseg.v4.operation.SecurityPolicyOptions import SecurityPolicyOptions  # noqa: F401,E501
from ntnx_microseg_py_client.models.microseg.v4.operation.SecurityPolicyType import SecurityPolicyType  # noqa: F401,E501

class PolicyMetadata(object):

    """The meta information about a Flow Network Security Policy.<br> The info captures the secured Categories, state of policy, policy type, last modified time, previewId and options.<br> The PreviewId can be used to fetch the complete FNS Next-Gen policy preview using Preview GET API.<br> A sample call would look like ``` /microseg/v4.0.a1/operation/policy-preview/8f094d6c-d7b2-32c2-8223-462c6c5e06db ``` 

    :param description: (:attr:`description`) A user defined annotation for a policy metadata during upgrade.
    :type description: 
     max=512 chars
    
    :param secured_group_category_references: (:attr:`secured_group_category_references`) List of categories external IDs being secured by the Flow Network Security Policy.
    :type secured_group_category_references: 
    
    
    :param state: (:attr:`state`) 
    :type state: required
    
    
    :param last_update_time: (:attr:`last_update_time`) Last update time for the network security policy.
    :type last_update_time: 
    
    
    :param type: (:attr:`type`) 
    :type type: 
    
    
    :param preview_reference: (:attr:`preview_reference`) This is a system generated identifier which can be used to preview the complete FNS Next-Gen policy corresponding with a FNS policy using Preview GET API. A sample call would look like ``` /microseg/v4.0.a1/operation/policy-preview/8f094d6c-d7b2-32c2-8223-462c6c5e06db ``` 
    :type preview_reference: 
    
    
    :param options: (:attr:`options`) 
    :type options: 
    
    
    :param name: (:attr:`name`) Name of the network security policy.
    :type name: 
     max=63 chars
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'description': 'str',
        'secured_group_category_references': 'list[str]',
        'state': 'microseg.v4.config.SecurityPolicyState',
        'last_update_time': 'datetime',
        'type': 'microseg.v4.operation.SecurityPolicyType',
        'preview_reference': 'str',
        'options': 'microseg.v4.operation.SecurityPolicyOptions',
        'name': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'description': 'description',
        'secured_group_category_references': 'securedGroupCategoryReferences',
        'state': 'state',
        'last_update_time': 'lastUpdateTime',
        'type': 'type',
        'preview_reference': 'previewReference',
        'options': 'options',
        'name': 'name',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, description=None, secured_group_category_references=None, state=None, last_update_time=None, type=None, preview_reference=None, options=None, name=None, *args, **kwargs):  # noqa: E501
        self.__description = None
        self.__secured_group_category_references = None
        self.__state = None
        self.__last_update_time = None
        self.__type = None
        self.__preview_reference = None
        self.__options = None
        self.__name = None
        self.discriminator = None
        if description is not None:
            self.__description = description
        if secured_group_category_references is not None:
            self.__secured_group_category_references = secured_group_category_references
        self.__state = state
        if last_update_time is not None:
            self.__last_update_time = last_update_time
        if type is not None:
            self.__type = type
        if preview_reference is not None:
            self.__preview_reference = preview_reference
        if options is not None:
            self.__options = options
        if name is not None:
            self.__name = name
        # populate hidden vars if not empty
        self._populate_hidden_vars(kwargs)

    def _initialize_object_type(self):
        return 'microseg.v4.operation.PolicyMetadata'

    def _initialize_object_version(self):
        return 'v4.r2'

    def _populate_hidden_vars(self, kwargs):
        if "_reserved" in kwargs and kwargs["_reserved"] is not None:
            self.__dollar_reserved = kwargs["_reserved"]
        elif hasattr(self, "attribute_map") and "_reserved" in self.attribute_map and self.attribute_map["_reserved"] in kwargs and kwargs[self.attribute_map["_reserved"]] is not None:
            self.__dollar_reserved = kwargs[self.attribute_map["_reserved"]]
        else :
            self.__dollar_reserved = {"$fv": self._initialize_object_version()}
        if "_unknown_fields" in kwargs and kwargs["_unknown_fields"] is not None:
            self.__dollar_unknown_fields = kwargs["_unknown_fields"]
        elif hasattr(self, "attribute_map") and "_unknown_fields" in self.attribute_map and self.attribute_map["_unknown_fields"] in kwargs and kwargs[self.attribute_map["_unknown_fields"]] is not None:
            self.__dollar_unknown_fields = kwargs[self.attribute_map["_unknown_fields"]]
        else :
            self.__dollar_unknown_fields = {}
        if "_object_type" in kwargs and kwargs["_object_type"] is not None:
            self.__dollar_object_type = kwargs["_object_type"]
        elif hasattr(self, "attribute_map") and "_object_type" in self.attribute_map and self.attribute_map["_object_type"] in kwargs and kwargs[self.attribute_map["_object_type"]] is not None:
            self.__dollar_object_type = kwargs[self.attribute_map["_object_type"]]
        else:
            self.__dollar_object_type = self._initialize_object_type()

    def get_object_type(self):
        return self.__dollar_object_type

    def get_reserved(self):
        return self.__dollar_reserved

    def get_unknown_fields(self):
        return self.__dollar_unknown_fields

    @property
    def description(self):
        """
        A user defined annotation for a policy metadata during upgrade.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__description

    @description.setter
    def description(self, description):
        if description is not None and len(description) > 512:
            raise ValueError("Invalid value for `description`, length must be less than or equal to `512`")  # noqa: E501

        self.__description = description

    @property
    def secured_group_category_references(self):
        """
        List of categories external IDs being secured by the Flow Network Security Policy.

        :type:
            list[ :class:`~str` ]
        """  # noqa: E501
        return self.__secured_group_category_references

    @secured_group_category_references.setter
    def secured_group_category_references(self, secured_group_category_references):

        self.__secured_group_category_references = secured_group_category_references

    @property
    def state(self):
        """
        

        :type:
            :class:`~ntnx_microseg_py_client.models.microseg.v4.config.SecurityPolicyState`
        """  # noqa: E501
        return self.__state

    @state.setter
    def state(self, state):
        if state is None:
            raise ValueError("Invalid value for `state`, must not be `None`")  # noqa: E501

        self.__state = state

    @property
    def last_update_time(self):
        """
        Last update time for the network security policy.

        :type:
                :class:`~datetime`
        """  # noqa: E501
        return self.__last_update_time

    @last_update_time.setter
    def last_update_time(self, last_update_time):

        self.__last_update_time = last_update_time

    @property
    def type(self):
        """
        

        :type:
            :class:`~ntnx_microseg_py_client.models.microseg.v4.operation.SecurityPolicyType`
        """  # noqa: E501
        return self.__type

    @type.setter
    def type(self, type):

        self.__type = type

    @property
    def preview_reference(self):
        """
        This is a system generated identifier which can be used to preview the complete FNS Next-Gen policy corresponding with a FNS policy using Preview GET API. A sample call would look like ``` /microseg/v4.0.a1/operation/policy-preview/8f094d6c-d7b2-32c2-8223-462c6c5e06db ``` 

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__preview_reference

    @preview_reference.setter
    def preview_reference(self, preview_reference):
        if preview_reference is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', preview_reference):  # noqa: E501
            raise ValueError(r"Invalid value for `preview_reference`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__preview_reference = preview_reference

    @property
    def options(self):
        """
        

        :type:
            :class:`~ntnx_microseg_py_client.models.microseg.v4.operation.SecurityPolicyOptions`
        """  # noqa: E501
        return self.__options

    @options.setter
    def options(self, options):

        self.__options = options

    @property
    def name(self):
        """
        Name of the network security policy.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__name

    @name.setter
    def name(self, name):
        if name is not None and len(name) > 63:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `63`")  # noqa: E501

        self.__name = name

    @property
    def _reserved(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_reserved

    @property
    def _object_type(self):
        """
        

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__dollar_object_type

    @property
    def _unknown_fields(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_unknown_fields

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(PolicyMetadata, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        # handle unknown fields
        result['_unknown_fields'] = {}
        unknown = self.get_unknown_fields()
        if sanitize:
            unknown = self._sanitize_for_serialization(unknown)

        return {**result, **unknown}

    def _sanitize_for_serialization(self, value):
        """Recursively sanitize the value for serialization.

        :param value: The value to sanitize
        :type value: any
        :return: Sanitized value
        :rtype: any
        """
        if isinstance(value, (list, tuple)):
            return list(map(self._sanitize_for_serialization, [v for v in value if v is not None]))
        elif isinstance(value, dict):
            return {k: self._sanitize_for_serialization(v) for k, v in six.iteritems(value) if v is not None}
        elif isinstance(value, (str, int, float, bool)):
            return value
        elif isinstance(value, Path):
            return str(value)
        else:
            return value.to_dict() if hasattr(value, 'to_dict') else str(value)

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PolicyMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Flow Management APIs

    Manage Network Security Policy configuration of Nutanix clusters.  # noqa: E501

    OpenAPI spec version: 4.2.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
from ntnx_microseg_py_client.models.common.v1.response.ApiLink import ApiLink  # noqa: F401,E501
from ntnx_microseg_py_client.models.common.v1.response.ExternalizableAbstractModel import ExternalizableAbstractModel  # noqa: F401,E501
from ntnx_microseg_py_client.models.microseg.v4.config.NetworkSecurityPolicyRule import NetworkSecurityPolicyRule  # noqa: F401,E501
from ntnx_microseg_py_client.models.microseg.v4.config.SecurityPolicyScope import SecurityPolicyScope  # noqa: F401,E501
from ntnx_microseg_py_client.models.microseg.v4.config.SecurityPolicyState import SecurityPolicyState  # noqa: F401,E501
from ntnx_microseg_py_client.models.microseg.v4.config.SecurityPolicyType import SecurityPolicyType  # noqa: F401,E501

class NetworkSecurityPolicy(ExternalizableAbstractModel):

    """A policy that contains rules for specifying security posture.

    :param name: (:attr:`name`) Name of the Flow Network Security Policy.<br> It can have a maximum length of 63 characters. 
    :type name: required
     max=63 chars
    
    :param type: (:attr:`type`) 
    :type type: required
    
    
    :param description: (:attr:`description`) A user defined annotation for a policy.
    :type description: 
     max=512 chars
    
    :param state: (:attr:`state`) 
    :type state: 
    
    
    :param rules: (:attr:`rules`) A list of rules that form a policy. For isolation policies, use isolation rules; for application or quarantine policies, use application rules.
    :type rules: 
    
    
    :param network_function_references: (:attr:`network_function_references`) List of network function external identifiers referenced in the policy.
    :type network_function_references: 
    
    
    :param is_ipv6_traffic_allowed: (:attr:`is_ipv6_traffic_allowed`) If enabled, IPv6 traffic is allowed regardless of policy configuration. If disabled, IPv6 traffic will follow the policy configuration (if isIpv6AddressScope is enabled).
    :type is_ipv6_traffic_allowed: 
    
    
    :param is_ipv4_address_scope: (:attr:`is_ipv4_address_scope`) If policy supports Ipv4 based rules
    :type is_ipv4_address_scope: 
    
    
    :param is_ipv6_address_scope: (:attr:`is_ipv6_address_scope`) If policy support Ipv6 based rules
    :type is_ipv6_address_scope: 
    
    
    :param is_hitlog_enabled: (:attr:`is_hitlog_enabled`) If Hitlog is enabled.
    :type is_hitlog_enabled: 
    
    
    :param scope: (:attr:`scope`) 
    :type scope: 
    
    
    :param vpc_references: (:attr:`vpc_references`) A list of external identifiers for VPCs, used only when the policy scope is a list of VPCs.
    :type vpc_references: 
    
    
    :param scope_references: (:attr:`scope_references`) A list of external identifiers, used only when the scope of policy is VPC as a category.
    :type scope_references: 
    
    
    :param secured_groups: (:attr:`secured_groups`) External identifiers of the categories in the secured groups in the Network Security Policy.
    :type secured_groups: 
    
    
    :param secured_entity_group_references: (:attr:`secured_entity_group_references`) External identifiers for entity groups within secured entities in the Network Security Policy.
    :type secured_entity_group_references: 
    
    
    :param last_update_time: (:attr:`last_update_time`) The timestamp when the Flow Network Security policy was last updated.
    :type last_update_time: 
    
    
    :param creation_time: (:attr:`creation_time`) The timestamp when the Flow Network Security policy was created.
    :type creation_time: 
    
    
    :param is_system_defined: (:attr:`is_system_defined`) A flag indicating whether the Flow Network Security policy is system-defined or not.
    :type is_system_defined: 
    
    
    :param created_by: (:attr:`created_by`) The extId of the user responsible for creating the Network Security Policy.
    :type created_by: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'name': 'str',
        'type': 'microseg.v4.config.SecurityPolicyType',
        'description': 'str',
        'state': 'microseg.v4.config.SecurityPolicyState',
        'rules': 'list[microseg.v4.config.NetworkSecurityPolicyRule]',
        'network_function_references': 'list[str]',
        'is_ipv6_traffic_allowed': 'bool',
        'is_ipv4_address_scope': 'bool',
        'is_ipv6_address_scope': 'bool',
        'is_hitlog_enabled': 'bool',
        'scope': 'microseg.v4.config.SecurityPolicyScope',
        'vpc_references': 'list[str]',
        'scope_references': 'list[str]',
        'secured_groups': 'list[str]',
        'secured_entity_group_references': 'list[str]',
        'last_update_time': 'datetime',
        'creation_time': 'datetime',
        'is_system_defined': 'bool',
        'created_by': 'str',
        'ext_id': 'str',
        'links': 'list[common.v1.response.ApiLink]',
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'name': 'name',
        'type': 'type',
        'description': 'description',
        'state': 'state',
        'rules': 'rules',
        'network_function_references': 'networkFunctionReferences',
        'is_ipv6_traffic_allowed': 'isIpv6TrafficAllowed',
        'is_ipv4_address_scope': 'isIpv4AddressScope',
        'is_ipv6_address_scope': 'isIpv6AddressScope',
        'is_hitlog_enabled': 'isHitlogEnabled',
        'scope': 'scope',
        'vpc_references': 'vpcReferences',
        'scope_references': 'scopeReferences',
        'secured_groups': 'securedGroups',
        'secured_entity_group_references': 'securedEntityGroupReferences',
        'last_update_time': 'lastUpdateTime',
        'creation_time': 'creationTime',
        'is_system_defined': 'isSystemDefined',
        'created_by': 'createdBy',
        'ext_id': 'extId',
        'links': 'links',
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, name=None, type=None, description=None, state=None, rules=None, network_function_references=None, is_ipv6_traffic_allowed=None, is_ipv4_address_scope=None, is_ipv6_address_scope=None, is_hitlog_enabled=None, scope=None, vpc_references=None, scope_references=None, secured_groups=None, secured_entity_group_references=None, last_update_time=None, creation_time=None, is_system_defined=None, created_by=None, ext_id=None, links=None, tenant_id=None, *args, **kwargs):  # noqa: E501
        ExternalizableAbstractModel.__init__(self, ext_id, links, tenant_id, *args, **kwargs)
        self.__name = None
        self.__type = None
        self.__description = None
        self.__state = None
        self.__rules = None
        self.__network_function_references = None
        self.__is_ipv6_traffic_allowed = None
        self.__is_ipv4_address_scope = None
        self.__is_ipv6_address_scope = None
        self.__is_hitlog_enabled = None
        self.__scope = None
        self.__vpc_references = None
        self.__scope_references = None
        self.__secured_groups = None
        self.__secured_entity_group_references = None
        self.__last_update_time = None
        self.__creation_time = None
        self.__is_system_defined = None
        self.__created_by = None
        self.discriminator = None
        self.__name = name
        self.__type = type
        if description is not None:
            self.__description = description
        if state is not None:
            self.__state = state
        if rules is not None:
            self.__rules = rules
        if network_function_references is not None:
            self.__network_function_references = network_function_references
        if is_ipv6_traffic_allowed is not None:
            self.__is_ipv6_traffic_allowed = is_ipv6_traffic_allowed
        if is_ipv4_address_scope is not None:
            self.__is_ipv4_address_scope = is_ipv4_address_scope
        if is_ipv6_address_scope is not None:
            self.__is_ipv6_address_scope = is_ipv6_address_scope
        if is_hitlog_enabled is not None:
            self.__is_hitlog_enabled = is_hitlog_enabled
        if scope is not None:
            self.__scope = scope
        if vpc_references is not None:
            self.__vpc_references = vpc_references
        if scope_references is not None:
            self.__scope_references = scope_references
        if secured_groups is not None:
            self.__secured_groups = secured_groups
        if secured_entity_group_references is not None:
            self.__secured_entity_group_references = secured_entity_group_references
        if last_update_time is not None:
            self.__last_update_time = last_update_time
        if creation_time is not None:
            self.__creation_time = creation_time
        if is_system_defined is not None:
            self.__is_system_defined = is_system_defined
        if created_by is not None:
            self.__created_by = created_by

    def _initialize_object_type(self):
        return 'microseg.v4.config.NetworkSecurityPolicy'

    def _initialize_object_version(self):
        return 'v4.r2'


    @property
    def name(self):
        """
        Name of the Flow Network Security Policy.<br> It can have a maximum length of 63 characters. 

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__name

    @name.setter
    def name(self, name):
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if name is not None and len(name) > 63:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `63`")  # noqa: E501
        if name is not None and not re.search('^\\s*[a-zA-Z0-9]([a-zA-Z0-9-_ \\\\.]*[a-zA-Z0-9])?\\s*$', name):  # noqa: E501
            raise ValueError(r"Invalid value for `name`, must be a follow pattern or equal to `/^\\s*[a-zA-Z0-9]([a-zA-Z0-9-_ \\\\.]*[a-zA-Z0-9])?\\s*$/`")  # noqa: E501

        self.__name = name

    @property
    def type(self):
        """
        

        :type:
            :class:`~ntnx_microseg_py_client.models.microseg.v4.config.SecurityPolicyType`
        """  # noqa: E501
        return self.__type

    @type.setter
    def type(self, type):
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self.__type = type

    @property
    def description(self):
        """
        A user defined annotation for a policy.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__description

    @description.setter
    def description(self, description):
        if description is not None and len(description) > 512:
            raise ValueError("Invalid value for `description`, length must be less than or equal to `512`")  # noqa: E501
        if description is not None and not re.search('^\\s*([a-zA-Z0-9 _:.()-]*)\\s*$', description):  # noqa: E501
            raise ValueError(r"Invalid value for `description`, must be a follow pattern or equal to `/^\\s*([a-zA-Z0-9 _:.()-]*)\\s*$/`")  # noqa: E501

        self.__description = description

    @property
    def state(self):
        """
        

        :type:
            :class:`~ntnx_microseg_py_client.models.microseg.v4.config.SecurityPolicyState`
        """  # noqa: E501
        return self.__state

    @state.setter
    def state(self, state):

        self.__state = state

    @property
    def rules(self):
        """
        A list of rules that form a policy. For isolation policies, use isolation rules; for application or quarantine policies, use application rules.

        :type:
             list[ :class:`~ntnx_microseg_py_client.models.microseg.v4.config.NetworkSecurityPolicyRule` ]
        """  # noqa: E501
        return self.__rules

    @rules.setter
    def rules(self, rules):

        self.__rules = rules

    @property
    def network_function_references(self):
        """
        List of network function external identifiers referenced in the policy.

        :type:
            list[ :class:`~str` ]
        """  # noqa: E501
        return self.__network_function_references

    @network_function_references.setter
    def network_function_references(self, network_function_references):

        self.__network_function_references = network_function_references

    @property
    def is_ipv6_traffic_allowed(self):
        """
        If enabled, IPv6 traffic is allowed regardless of policy configuration. If disabled, IPv6 traffic will follow the policy configuration (if isIpv6AddressScope is enabled).

        :type:
                :class:`~bool`
        """  # noqa: E501
        return self.__is_ipv6_traffic_allowed

    @is_ipv6_traffic_allowed.setter
    def is_ipv6_traffic_allowed(self, is_ipv6_traffic_allowed):

        self.__is_ipv6_traffic_allowed = is_ipv6_traffic_allowed

    @property
    def is_ipv4_address_scope(self):
        """
        If policy supports Ipv4 based rules

        :type:
                :class:`~bool`
        """  # noqa: E501
        return self.__is_ipv4_address_scope

    @is_ipv4_address_scope.setter
    def is_ipv4_address_scope(self, is_ipv4_address_scope):

        self.__is_ipv4_address_scope = is_ipv4_address_scope

    @property
    def is_ipv6_address_scope(self):
        """
        If policy support Ipv6 based rules

        :type:
                :class:`~bool`
        """  # noqa: E501
        return self.__is_ipv6_address_scope

    @is_ipv6_address_scope.setter
    def is_ipv6_address_scope(self, is_ipv6_address_scope):

        self.__is_ipv6_address_scope = is_ipv6_address_scope

    @property
    def is_hitlog_enabled(self):
        """
        If Hitlog is enabled.

        :type:
                :class:`~bool`
        """  # noqa: E501
        return self.__is_hitlog_enabled

    @is_hitlog_enabled.setter
    def is_hitlog_enabled(self, is_hitlog_enabled):

        self.__is_hitlog_enabled = is_hitlog_enabled

    @property
    def scope(self):
        """
        

        :type:
            :class:`~ntnx_microseg_py_client.models.microseg.v4.config.SecurityPolicyScope`
        """  # noqa: E501
        return self.__scope

    @scope.setter
    def scope(self, scope):

        self.__scope = scope

    @property
    def vpc_references(self):
        """
        A list of external identifiers for VPCs, used only when the policy scope is a list of VPCs.

        :type:
            list[ :class:`~str` ]
        """  # noqa: E501
        return self.__vpc_references

    @vpc_references.setter
    def vpc_references(self, vpc_references):

        self.__vpc_references = vpc_references

    @property
    def scope_references(self):
        """
        A list of external identifiers, used only when the scope of policy is VPC as a category.

        :type:
            list[ :class:`~str` ]
        """  # noqa: E501
        return self.__scope_references

    @scope_references.setter
    def scope_references(self, scope_references):

        self.__scope_references = scope_references

    @property
    def secured_groups(self):
        """
        External identifiers of the categories in the secured groups in the Network Security Policy.

        :type:
            list[ :class:`~str` ]
        """  # noqa: E501
        return self.__secured_groups

    @secured_groups.setter
    def secured_groups(self, secured_groups):

        self.__secured_groups = secured_groups

    @property
    def secured_entity_group_references(self):
        """
        External identifiers for entity groups within secured entities in the Network Security Policy.

        :type:
            list[ :class:`~str` ]
        """  # noqa: E501
        return self.__secured_entity_group_references

    @secured_entity_group_references.setter
    def secured_entity_group_references(self, secured_entity_group_references):

        self.__secured_entity_group_references = secured_entity_group_references

    @property
    def last_update_time(self):
        """
        The timestamp when the Flow Network Security policy was last updated.

        :type:
                :class:`~datetime`
        """  # noqa: E501
        return self.__last_update_time

    @last_update_time.setter
    def last_update_time(self, last_update_time):

        self.__last_update_time = last_update_time

    @property
    def creation_time(self):
        """
        The timestamp when the Flow Network Security policy was created.

        :type:
                :class:`~datetime`
        """  # noqa: E501
        return self.__creation_time

    @creation_time.setter
    def creation_time(self, creation_time):

        self.__creation_time = creation_time

    @property
    def is_system_defined(self):
        """
        A flag indicating whether the Flow Network Security policy is system-defined or not.

        :type:
                :class:`~bool`
        """  # noqa: E501
        return self.__is_system_defined

    @is_system_defined.setter
    def is_system_defined(self, is_system_defined):

        self.__is_system_defined = is_system_defined

    @property
    def created_by(self):
        """
        The extId of the user responsible for creating the Network Security Policy.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__created_by

    @created_by.setter
    def created_by(self, created_by):
        if created_by is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', created_by):  # noqa: E501
            raise ValueError(r"Invalid value for `created_by`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__created_by = created_by

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(NetworkSecurityPolicy, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        # handle unknown fields
        result['_unknown_fields'] = {}
        unknown = self.get_unknown_fields()
        if sanitize:
            unknown = self._sanitize_for_serialization(unknown)

        return {**result, **unknown}


    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NetworkSecurityPolicy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Flow Management APIs

    Manage Network Security Policy configuration of Nutanix clusters.  # noqa: E501

    OpenAPI spec version: 4.2.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
from ntnx_microseg_py_client.models.common.v1.response.ApiLink import ApiLink  # noqa: F401,E501
from ntnx_microseg_py_client.models.common.v1.response.ExternalizableAbstractModel import ExternalizableAbstractModel  # noqa: F401,E501

class SyncPolicy(ExternalizableAbstractModel):

    """

    :param source_domain_manager_ext_id: (:attr:`source_domain_manager_ext_id`) Prism Central from which security policies are being synchronized.
    :type source_domain_manager_ext_id: required
    
    
    :param target_domain_manager_ext_id: (:attr:`target_domain_manager_ext_id`) Prism Central to which security policies are synchronized.
    :type target_domain_manager_ext_id: required
    
    
    :param policy_ext_ids: (:attr:`policy_ext_ids`) List of security policies that are synchronized across a Prism Central pair.
    :type policy_ext_ids: 
    
    
    :param has_sync_compatibility: (:attr:`has_sync_compatibility`) State of the Prism Central pair that determines its capability to synchronize security policies.
    :type has_sync_compatibility: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'source_domain_manager_ext_id': 'str',
        'target_domain_manager_ext_id': 'str',
        'policy_ext_ids': 'list[str]',
        'has_sync_compatibility': 'bool',
        'ext_id': 'str',
        'links': 'list[common.v1.response.ApiLink]',
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'source_domain_manager_ext_id': 'sourceDomainManagerExtId',
        'target_domain_manager_ext_id': 'targetDomainManagerExtId',
        'policy_ext_ids': 'policyExtIds',
        'has_sync_compatibility': 'hasSyncCompatibility',
        'ext_id': 'extId',
        'links': 'links',
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, source_domain_manager_ext_id=None, target_domain_manager_ext_id=None, policy_ext_ids=None, has_sync_compatibility=None, ext_id=None, links=None, tenant_id=None, *args, **kwargs):  # noqa: E501
        ExternalizableAbstractModel.__init__(self, ext_id, links, tenant_id, *args, **kwargs)
        self.__source_domain_manager_ext_id = None
        self.__target_domain_manager_ext_id = None
        self.__policy_ext_ids = None
        self.__has_sync_compatibility = None
        self.discriminator = None
        self.__source_domain_manager_ext_id = source_domain_manager_ext_id
        self.__target_domain_manager_ext_id = target_domain_manager_ext_id
        if policy_ext_ids is not None:
            self.__policy_ext_ids = policy_ext_ids
        if has_sync_compatibility is not None:
            self.__has_sync_compatibility = has_sync_compatibility

    def _initialize_object_type(self):
        return 'microseg.v4.config.SyncPolicy'

    def _initialize_object_version(self):
        return 'v4.r2'


    @property
    def source_domain_manager_ext_id(self):
        """
        Prism Central from which security policies are being synchronized.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__source_domain_manager_ext_id

    @source_domain_manager_ext_id.setter
    def source_domain_manager_ext_id(self, source_domain_manager_ext_id):
        if source_domain_manager_ext_id is None:
            raise ValueError("Invalid value for `source_domain_manager_ext_id`, must not be `None`")  # noqa: E501
        if source_domain_manager_ext_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', source_domain_manager_ext_id):  # noqa: E501
            raise ValueError(r"Invalid value for `source_domain_manager_ext_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__source_domain_manager_ext_id = source_domain_manager_ext_id

    @property
    def target_domain_manager_ext_id(self):
        """
        Prism Central to which security policies are synchronized.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__target_domain_manager_ext_id

    @target_domain_manager_ext_id.setter
    def target_domain_manager_ext_id(self, target_domain_manager_ext_id):
        if target_domain_manager_ext_id is None:
            raise ValueError("Invalid value for `target_domain_manager_ext_id`, must not be `None`")  # noqa: E501
        if target_domain_manager_ext_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', target_domain_manager_ext_id):  # noqa: E501
            raise ValueError(r"Invalid value for `target_domain_manager_ext_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__target_domain_manager_ext_id = target_domain_manager_ext_id

    @property
    def policy_ext_ids(self):
        """
        List of security policies that are synchronized across a Prism Central pair.

        :type:
            list[ :class:`~str` ]
        """  # noqa: E501
        return self.__policy_ext_ids

    @policy_ext_ids.setter
    def policy_ext_ids(self, policy_ext_ids):

        self.__policy_ext_ids = policy_ext_ids

    @property
    def has_sync_compatibility(self):
        """
        State of the Prism Central pair that determines its capability to synchronize security policies.

        :type:
                :class:`~bool`
        """  # noqa: E501
        return self.__has_sync_compatibility

    @has_sync_compatibility.setter
    def has_sync_compatibility(self, has_sync_compatibility):

        self.__has_sync_compatibility = has_sync_compatibility

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(SyncPolicy, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        # handle unknown fields
        result['_unknown_fields'] = {}
        unknown = self.get_unknown_fields()
        if sanitize:
            unknown = self._sanitize_for_serialization(unknown)

        return {**result, **unknown}


    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SyncPolicy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Flow Management APIs

    Manage Network Security Policy configuration of Nutanix clusters.  # noqa: E501

    OpenAPI spec version: 4.2.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
from ntnx_microseg_py_client.models.common.v1.config.IPAddressOrFQDN import IPAddressOrFQDN  # noqa: F401,E501
from ntnx_microseg_py_client.models.common.v1.response.ApiLink import ApiLink  # noqa: F401,E501
from ntnx_microseg_py_client.models.common.v1.response.ExternalizableAbstractModel import ExternalizableAbstractModel  # noqa: F401,E501
from ntnx_microseg_py_client.models.microseg.v4.config.MatchingCriteria import MatchingCriteria  # noqa: F401,E501

class DirectoryServerConfig(ExternalizableAbstractModel):

    """

    :param is_default_category_enabled: (:attr:`is_default_category_enabled`) Enablement status of the default category.
    :type is_default_category_enabled: 
    
    
    :param should_keep_default_category_on_login: (:attr:`should_keep_default_category_on_login`) Retain default category on user login.
    :type should_keep_default_category_on_login: 
    
    
    :param matching_criterias: (:attr:`matching_criterias`) The matching criteria used to determine whether an entity will be categorized by identity categorization. If match type is ALL, all the entities will be categorized.
    :type matching_criterias: 
    
    
    :param directory_service_reference: (:attr:`directory_service_reference`) The ExtID of the directory service that will be used for mapping.
    :type directory_service_reference: 
    
    
    :param domain_controllers: (:attr:`domain_controllers`) List of domain controllers to be used for event scraping.
    :type domain_controllers: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'is_default_category_enabled': 'bool',
        'should_keep_default_category_on_login': 'bool',
        'matching_criterias': 'list[microseg.v4.config.MatchingCriteria]',
        'directory_service_reference': 'str',
        'domain_controllers': 'list[common.v1.config.IPAddressOrFQDN]',
        'ext_id': 'str',
        'links': 'list[common.v1.response.ApiLink]',
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'is_default_category_enabled': 'isDefaultCategoryEnabled',
        'should_keep_default_category_on_login': 'shouldKeepDefaultCategoryOnLogin',
        'matching_criterias': 'matchingCriterias',
        'directory_service_reference': 'directoryServiceReference',
        'domain_controllers': 'domainControllers',
        'ext_id': 'extId',
        'links': 'links',
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, is_default_category_enabled=None, should_keep_default_category_on_login=None, matching_criterias=None, directory_service_reference=None, domain_controllers=None, ext_id=None, links=None, tenant_id=None, *args, **kwargs):  # noqa: E501
        ExternalizableAbstractModel.__init__(self, ext_id, links, tenant_id, *args, **kwargs)
        self.__is_default_category_enabled = None
        self.__should_keep_default_category_on_login = None
        self.__matching_criterias = None
        self.__directory_service_reference = None
        self.__domain_controllers = None
        self.discriminator = None
        if is_default_category_enabled is not None:
            self.__is_default_category_enabled = is_default_category_enabled
        if should_keep_default_category_on_login is not None:
            self.__should_keep_default_category_on_login = should_keep_default_category_on_login
        if matching_criterias is not None:
            self.__matching_criterias = matching_criterias
        if directory_service_reference is not None:
            self.__directory_service_reference = directory_service_reference
        if domain_controllers is not None:
            self.__domain_controllers = domain_controllers

    def _initialize_object_type(self):
        return 'microseg.v4.config.DirectoryServerConfig'

    def _initialize_object_version(self):
        return 'v4.r2'


    @property
    def is_default_category_enabled(self):
        """
        Enablement status of the default category.

        :type:
                :class:`~bool`
        """  # noqa: E501
        return self.__is_default_category_enabled

    @is_default_category_enabled.setter
    def is_default_category_enabled(self, is_default_category_enabled):

        self.__is_default_category_enabled = is_default_category_enabled

    @property
    def should_keep_default_category_on_login(self):
        """
        Retain default category on user login.

        :type:
                :class:`~bool`
        """  # noqa: E501
        return self.__should_keep_default_category_on_login

    @should_keep_default_category_on_login.setter
    def should_keep_default_category_on_login(self, should_keep_default_category_on_login):

        self.__should_keep_default_category_on_login = should_keep_default_category_on_login

    @property
    def matching_criterias(self):
        """
        The matching criteria used to determine whether an entity will be categorized by identity categorization. If match type is ALL, all the entities will be categorized.

        :type:
             list[ :class:`~ntnx_microseg_py_client.models.microseg.v4.config.MatchingCriteria` ]
        """  # noqa: E501
        return self.__matching_criterias

    @matching_criterias.setter
    def matching_criterias(self, matching_criterias):

        self.__matching_criterias = matching_criterias

    @property
    def directory_service_reference(self):
        """
        The ExtID of the directory service that will be used for mapping.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__directory_service_reference

    @directory_service_reference.setter
    def directory_service_reference(self, directory_service_reference):
        if directory_service_reference is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', directory_service_reference):  # noqa: E501
            raise ValueError(r"Invalid value for `directory_service_reference`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__directory_service_reference = directory_service_reference

    @property
    def domain_controllers(self):
        """
        List of domain controllers to be used for event scraping.

        :type:
             list[ :class:`~ntnx_microseg_py_client.models.common.v1.config.IPAddressOrFQDN` ]
        """  # noqa: E501
        return self.__domain_controllers

    @domain_controllers.setter
    def domain_controllers(self, domain_controllers):

        self.__domain_controllers = domain_controllers

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(DirectoryServerConfig, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        # handle unknown fields
        result['_unknown_fields'] = {}
        unknown = self.get_unknown_fields()
        if sanitize:
            unknown = self._sanitize_for_serialization(unknown)

        return {**result, **unknown}


    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DirectoryServerConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Flow Management APIs

    Manage Network Security Policy configuration of Nutanix clusters.  # noqa: E501

    OpenAPI spec version: 4.2.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path

class UpgradeSpec(object):

    """__Request body for Actual Config Upgrade__  It contains two required fields: - forceMonitor - upgradeSecuredSubnets 

    :param should_set_monitor_mode: (:attr:`should_set_monitor_mode`) If set to true, it forces all the policies to be in monitor mode after the upgrade completes. For the default false case, all the policies would remain in the same pre-upgrade state. 
    :type should_set_monitor_mode: required
    
    
    :param should_upgrade_secured_subnets_only: (:attr:`should_upgrade_secured_subnets_only`) If set to true, only the subnets with NSP secured VMs are upgraded. For the value set to false, all the subnets are upgraded. 
    :type should_upgrade_secured_subnets_only: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'should_set_monitor_mode': 'bool',
        'should_upgrade_secured_subnets_only': 'bool',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'should_set_monitor_mode': 'shouldSetMonitorMode',
        'should_upgrade_secured_subnets_only': 'shouldUpgradeSecuredSubnetsOnly',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, should_set_monitor_mode=None, should_upgrade_secured_subnets_only=None, *args, **kwargs):  # noqa: E501
        self.__should_set_monitor_mode = None
        self.__should_upgrade_secured_subnets_only = None
        self.discriminator = None
        self.__should_set_monitor_mode = should_set_monitor_mode
        if should_upgrade_secured_subnets_only is not None:
            self.__should_upgrade_secured_subnets_only = should_upgrade_secured_subnets_only
        # populate hidden vars if not empty
        self._populate_hidden_vars(kwargs)

    def _initialize_object_type(self):
        return 'microseg.v4.operation.UpgradeSpec'

    def _initialize_object_version(self):
        return 'v4.r2'

    def _populate_hidden_vars(self, kwargs):
        if "_reserved" in kwargs and kwargs["_reserved"] is not None:
            self.__dollar_reserved = kwargs["_reserved"]
        elif hasattr(self, "attribute_map") and "_reserved" in self.attribute_map and self.attribute_map["_reserved"] in kwargs and kwargs[self.attribute_map["_reserved"]] is not None:
            self.__dollar_reserved = kwargs[self.attribute_map["_reserved"]]
        else :
            self.__dollar_reserved = {"$fv": self._initialize_object_version()}
        if "_unknown_fields" in kwargs and kwargs["_unknown_fields"] is not None:
            self.__dollar_unknown_fields = kwargs["_unknown_fields"]
        elif hasattr(self, "attribute_map") and "_unknown_fields" in self.attribute_map and self.attribute_map["_unknown_fields"] in kwargs and kwargs[self.attribute_map["_unknown_fields"]] is not None:
            self.__dollar_unknown_fields = kwargs[self.attribute_map["_unknown_fields"]]
        else :
            self.__dollar_unknown_fields = {}
        if "_object_type" in kwargs and kwargs["_object_type"] is not None:
            self.__dollar_object_type = kwargs["_object_type"]
        elif hasattr(self, "attribute_map") and "_object_type" in self.attribute_map and self.attribute_map["_object_type"] in kwargs and kwargs[self.attribute_map["_object_type"]] is not None:
            self.__dollar_object_type = kwargs[self.attribute_map["_object_type"]]
        else:
            self.__dollar_object_type = self._initialize_object_type()

    def get_object_type(self):
        return self.__dollar_object_type

    def get_reserved(self):
        return self.__dollar_reserved

    def get_unknown_fields(self):
        return self.__dollar_unknown_fields

    @property
    def should_set_monitor_mode(self):
        """
        If set to true, it forces all the policies to be in monitor mode after the upgrade completes. For the default false case, all the policies would remain in the same pre-upgrade state. 

        :type:
                :class:`~bool`
        """  # noqa: E501
        return self.__should_set_monitor_mode

    @should_set_monitor_mode.setter
    def should_set_monitor_mode(self, should_set_monitor_mode):
        if should_set_monitor_mode is None:
            raise ValueError("Invalid value for `should_set_monitor_mode`, must not be `None`")  # noqa: E501

        self.__should_set_monitor_mode = should_set_monitor_mode

    @property
    def should_upgrade_secured_subnets_only(self):
        """
        If set to true, only the subnets with NSP secured VMs are upgraded. For the value set to false, all the subnets are upgraded. 

        :type:
                :class:`~bool`
        """  # noqa: E501
        return self.__should_upgrade_secured_subnets_only

    @should_upgrade_secured_subnets_only.setter
    def should_upgrade_secured_subnets_only(self, should_upgrade_secured_subnets_only):

        self.__should_upgrade_secured_subnets_only = should_upgrade_secured_subnets_only

    @property
    def _reserved(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_reserved

    @property
    def _object_type(self):
        """
        

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__dollar_object_type

    @property
    def _unknown_fields(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_unknown_fields

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(UpgradeSpec, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        # handle unknown fields
        result['_unknown_fields'] = {}
        unknown = self.get_unknown_fields()
        if sanitize:
            unknown = self._sanitize_for_serialization(unknown)

        return {**result, **unknown}

    def _sanitize_for_serialization(self, value):
        """Recursively sanitize the value for serialization.

        :param value: The value to sanitize
        :type value: any
        :return: Sanitized value
        :rtype: any
        """
        if isinstance(value, (list, tuple)):
            return list(map(self._sanitize_for_serialization, [v for v in value if v is not None]))
        elif isinstance(value, dict):
            return {k: self._sanitize_for_serialization(v) for k, v in six.iteritems(value) if v is not None}
        elif isinstance(value, (str, int, float, bool)):
            return value
        elif isinstance(value, Path):
            return str(value)
        else:
            return value.to_dict() if hasattr(value, 'to_dict') else str(value)

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpgradeSpec):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Flow Management APIs

    Manage Network Security Policy configuration of Nutanix clusters.  # noqa: E501

    OpenAPI spec version: 4.2.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
import ntnx_microseg_py_client.models
from ntnx_microseg_py_client.models.OneOfmicroseg.v4.config.GetDsCategoryMappingApiResponsedata import GetDsCategoryMappingApiResponsedata  # noqa: F401,E501
from ntnx_microseg_py_client.models.common.v1.response.ApiResponseMetadata import ApiResponseMetadata  # noqa: F401,E501

class GetDsCategoryMappingApiResponse(object):

    """REST response for all response codes in API path /microseg/v4.2/config/category-mappings/{extId} Get operation

    :param metadata: (:attr:`metadata`) 
    :type metadata: 
    
    
    :param data: (:attr:`data`) 
    :type data: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'metadata': 'common.v1.response.ApiResponseMetadata',
        'data': 'OneOfmicroseg.v4.config.GetDsCategoryMappingApiResponsedata',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'metadata': 'metadata',
        'data': 'data',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, metadata=None, data=None, *args, **kwargs):  # noqa: E501
        self.__metadata = None
        self.__data = None
        self.discriminator = None
        if metadata is not None:
            self.__metadata = metadata
        if data is not None:
            self.__data = data
        # populate hidden vars if not empty
        self._populate_hidden_vars(kwargs)

    def _initialize_object_type(self):
        return 'microseg.v4.config.GetDsCategoryMappingApiResponse'

    def _initialize_object_version(self):
        return 'v4.r2'

    def _populate_hidden_vars(self, kwargs):
        if "_reserved" in kwargs and kwargs["_reserved"] is not None:
            self.__dollar_reserved = kwargs["_reserved"]
        elif hasattr(self, "attribute_map") and "_reserved" in self.attribute_map and self.attribute_map["_reserved"] in kwargs and kwargs[self.attribute_map["_reserved"]] is not None:
            self.__dollar_reserved = kwargs[self.attribute_map["_reserved"]]
        else :
            self.__dollar_reserved = {"$fv": self._initialize_object_version()}
        if "_unknown_fields" in kwargs and kwargs["_unknown_fields"] is not None:
            self.__dollar_unknown_fields = kwargs["_unknown_fields"]
        elif hasattr(self, "attribute_map") and "_unknown_fields" in self.attribute_map and self.attribute_map["_unknown_fields"] in kwargs and kwargs[self.attribute_map["_unknown_fields"]] is not None:
            self.__dollar_unknown_fields = kwargs[self.attribute_map["_unknown_fields"]]
        else :
            self.__dollar_unknown_fields = {}
        if "_object_type" in kwargs and kwargs["_object_type"] is not None:
            self.__dollar_object_type = kwargs["_object_type"]
        elif hasattr(self, "attribute_map") and "_object_type" in self.attribute_map and self.attribute_map["_object_type"] in kwargs and kwargs[self.attribute_map["_object_type"]] is not None:
            self.__dollar_object_type = kwargs[self.attribute_map["_object_type"]]
        else:
            self.__dollar_object_type = self._initialize_object_type()

    def get_object_type(self):
        return self.__dollar_object_type

    def get_reserved(self):
        return self.__dollar_reserved

    def get_unknown_fields(self):
        return self.__dollar_unknown_fields

    @property
    def metadata(self):
        """
        

        :type:
            :class:`~ntnx_microseg_py_client.models.common.v1.response.ApiResponseMetadata`
        """  # noqa: E501
        return self.__metadata

    @metadata.setter
    def metadata(self, metadata):

        self.__metadata = metadata

    @property
    def data(self):
        """
        

        :type:
                :class:`~ntnx_microseg_py_client.models.microseg.v4.config.CategoryMapping` | 
                :class:`~ntnx_microseg_py_client.models.microseg.v4.error.ErrorResponse`
        """  # noqa: E501
        return self.__data

    @data.setter
    def data(self, data):

        self.__data = data

    @property
    def _reserved(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_reserved

    @property
    def _object_type(self):
        """
        

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__dollar_object_type

    @property
    def _unknown_fields(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_unknown_fields

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if attr_type.startswith('OneOf'):
                type = getattr(ntnx_microseg_py_client.models, attr_type.split('.')[-1])
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(GetDsCategoryMappingApiResponse, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        # handle unknown fields
        result['_unknown_fields'] = {}
        unknown = self.get_unknown_fields()
        if sanitize:
            unknown = self._sanitize_for_serialization(unknown)

        return {**result, **unknown}

    def _sanitize_for_serialization(self, value):
        """Recursively sanitize the value for serialization.

        :param value: The value to sanitize
        :type value: any
        :return: Sanitized value
        :rtype: any
        """
        if isinstance(value, (list, tuple)):
            return list(map(self._sanitize_for_serialization, [v for v in value if v is not None]))
        elif isinstance(value, dict):
            return {k: self._sanitize_for_serialization(v) for k, v in six.iteritems(value) if v is not None}
        elif isinstance(value, (str, int, float, bool)):
            return value
        elif isinstance(value, Path):
            return str(value)
        else:
            return value.to_dict() if hasattr(value, 'to_dict') else str(value)

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetDsCategoryMappingApiResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Flow Management APIs

    Manage Network Security Policy configuration of Nutanix clusters.  # noqa: E501

    OpenAPI spec version: 4.2.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
from ntnx_microseg_py_client.models.microseg.v4.config.CategoryAssociatedEntityType import CategoryAssociatedEntityType  # noqa: F401,E501
from ntnx_microseg_py_client.models.microseg.v4.config.IcmpTypeCodeSpec import IcmpTypeCodeSpec  # noqa: F401,E501
from ntnx_microseg_py_client.models.microseg.v4.config.IcmpV6TypeCodeSpec import IcmpV6TypeCodeSpec  # noqa: F401,E501
from ntnx_microseg_py_client.models.microseg.v4.config.IntraEntityGroupRuleAction import IntraEntityGroupRuleAction  # noqa: F401,E501
from ntnx_microseg_py_client.models.microseg.v4.config.TcpPortRangeSpec import TcpPortRangeSpec  # noqa: F401,E501
from ntnx_microseg_py_client.models.microseg.v4.config.UdpPortRangeSpec import UdpPortRangeSpec  # noqa: F401,E501

class IntraEntityGroupRuleSpec(object):

    """A rule for specifying allowed traffic inside a secured entity group.

    :param secured_group_category_associated_entity_type: (:attr:`secured_group_category_associated_entity_type`) 
    :type secured_group_category_associated_entity_type: 
    
    
    :param secured_group_category_references: (:attr:`secured_group_category_references`) A set of network endpoints which is protected by a Network Security Policy and defined as a list of categories.
    :type secured_group_category_references: 
    
    
    :param secured_group_entity_group_reference: (:attr:`secured_group_entity_group_reference`) External identifier of the entity group belonging to the secured group.
    :type secured_group_entity_group_reference: 
    
    
    :param secured_group_action: (:attr:`secured_group_action`) 
    :type secured_group_action: required
    
    
    :param secured_group_service_references: (:attr:`secured_group_service_references`) A list of service group references.
    :type secured_group_service_references: 
    
    
    :param tcp_services: (:attr:`tcp_services`) 
    :type tcp_services: 
    
    
    :param udp_services: (:attr:`udp_services`) 
    :type udp_services: 
    
    
    :param icmp_services: (:attr:`icmp_services`) ICMP Type Code List.
    :type icmp_services: 
    
    
    :param icmp_v6_services: (:attr:`icmp_v6_services`) ICMPv6 Type Code List.
    :type icmp_v6_services: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'secured_group_category_associated_entity_type': 'microseg.v4.config.CategoryAssociatedEntityType',
        'secured_group_category_references': 'list[str]',
        'secured_group_entity_group_reference': 'str',
        'secured_group_action': 'microseg.v4.config.IntraEntityGroupRuleAction',
        'secured_group_service_references': 'list[str]',
        'tcp_services': 'list[microseg.v4.config.TcpPortRangeSpec]',
        'udp_services': 'list[microseg.v4.config.UdpPortRangeSpec]',
        'icmp_services': 'list[microseg.v4.config.IcmpTypeCodeSpec]',
        'icmp_v6_services': 'list[microseg.v4.config.IcmpV6TypeCodeSpec]',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'secured_group_category_associated_entity_type': 'securedGroupCategoryAssociatedEntityType',
        'secured_group_category_references': 'securedGroupCategoryReferences',
        'secured_group_entity_group_reference': 'securedGroupEntityGroupReference',
        'secured_group_action': 'securedGroupAction',
        'secured_group_service_references': 'securedGroupServiceReferences',
        'tcp_services': 'tcpServices',
        'udp_services': 'udpServices',
        'icmp_services': 'icmpServices',
        'icmp_v6_services': 'icmpV6Services',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, secured_group_category_associated_entity_type=None, secured_group_category_references=None, secured_group_entity_group_reference=None, secured_group_action=None, secured_group_service_references=None, tcp_services=None, udp_services=None, icmp_services=None, icmp_v6_services=None, *args, **kwargs):  # noqa: E501
        self.__secured_group_category_associated_entity_type = None
        self.__secured_group_category_references = None
        self.__secured_group_entity_group_reference = None
        self.__secured_group_action = None
        self.__secured_group_service_references = None
        self.__tcp_services = None
        self.__udp_services = None
        self.__icmp_services = None
        self.__icmp_v6_services = None
        self.discriminator = None
        if secured_group_category_associated_entity_type is not None:
            self.__secured_group_category_associated_entity_type = secured_group_category_associated_entity_type
        if secured_group_category_references is not None:
            self.__secured_group_category_references = secured_group_category_references
        if secured_group_entity_group_reference is not None:
            self.__secured_group_entity_group_reference = secured_group_entity_group_reference
        self.__secured_group_action = secured_group_action
        if secured_group_service_references is not None:
            self.__secured_group_service_references = secured_group_service_references
        if tcp_services is not None:
            self.__tcp_services = tcp_services
        if udp_services is not None:
            self.__udp_services = udp_services
        if icmp_services is not None:
            self.__icmp_services = icmp_services
        if icmp_v6_services is not None:
            self.__icmp_v6_services = icmp_v6_services
        # populate hidden vars if not empty
        self._populate_hidden_vars(kwargs)

    def _initialize_object_type(self):
        return 'microseg.v4.config.IntraEntityGroupRuleSpec'

    def _initialize_object_version(self):
        return 'v4.r2'

    def _populate_hidden_vars(self, kwargs):
        if "_reserved" in kwargs and kwargs["_reserved"] is not None:
            self.__dollar_reserved = kwargs["_reserved"]
        elif hasattr(self, "attribute_map") and "_reserved" in self.attribute_map and self.attribute_map["_reserved"] in kwargs and kwargs[self.attribute_map["_reserved"]] is not None:
            self.__dollar_reserved = kwargs[self.attribute_map["_reserved"]]
        else :
            self.__dollar_reserved = {"$fv": self._initialize_object_version()}
        if "_unknown_fields" in kwargs and kwargs["_unknown_fields"] is not None:
            self.__dollar_unknown_fields = kwargs["_unknown_fields"]
        elif hasattr(self, "attribute_map") and "_unknown_fields" in self.attribute_map and self.attribute_map["_unknown_fields"] in kwargs and kwargs[self.attribute_map["_unknown_fields"]] is not None:
            self.__dollar_unknown_fields = kwargs[self.attribute_map["_unknown_fields"]]
        else :
            self.__dollar_unknown_fields = {}
        if "_object_type" in kwargs and kwargs["_object_type"] is not None:
            self.__dollar_object_type = kwargs["_object_type"]
        elif hasattr(self, "attribute_map") and "_object_type" in self.attribute_map and self.attribute_map["_object_type"] in kwargs and kwargs[self.attribute_map["_object_type"]] is not None:
            self.__dollar_object_type = kwargs[self.attribute_map["_object_type"]]
        else:
            self.__dollar_object_type = self._initialize_object_type()

    def get_object_type(self):
        return self.__dollar_object_type

    def get_reserved(self):
        return self.__dollar_reserved

    def get_unknown_fields(self):
        return self.__dollar_unknown_fields

    @property
    def secured_group_category_associated_entity_type(self):
        """
        

        :type:
            :class:`~ntnx_microseg_py_client.models.microseg.v4.config.CategoryAssociatedEntityType`
        """  # noqa: E501
        return self.__secured_group_category_associated_entity_type

    @secured_group_category_associated_entity_type.setter
    def secured_group_category_associated_entity_type(self, secured_group_category_associated_entity_type):

        self.__secured_group_category_associated_entity_type = secured_group_category_associated_entity_type

    @property
    def secured_group_category_references(self):
        """
        A set of network endpoints which is protected by a Network Security Policy and defined as a list of categories.

        :type:
            list[ :class:`~str` ]
        """  # noqa: E501
        return self.__secured_group_category_references

    @secured_group_category_references.setter
    def secured_group_category_references(self, secured_group_category_references):

        self.__secured_group_category_references = secured_group_category_references

    @property
    def secured_group_entity_group_reference(self):
        """
        External identifier of the entity group belonging to the secured group.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__secured_group_entity_group_reference

    @secured_group_entity_group_reference.setter
    def secured_group_entity_group_reference(self, secured_group_entity_group_reference):
        if secured_group_entity_group_reference is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', secured_group_entity_group_reference):  # noqa: E501
            raise ValueError(r"Invalid value for `secured_group_entity_group_reference`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__secured_group_entity_group_reference = secured_group_entity_group_reference

    @property
    def secured_group_action(self):
        """
        

        :type:
            :class:`~ntnx_microseg_py_client.models.microseg.v4.config.IntraEntityGroupRuleAction`
        """  # noqa: E501
        return self.__secured_group_action

    @secured_group_action.setter
    def secured_group_action(self, secured_group_action):
        if secured_group_action is None:
            raise ValueError("Invalid value for `secured_group_action`, must not be `None`")  # noqa: E501

        self.__secured_group_action = secured_group_action

    @property
    def secured_group_service_references(self):
        """
        A list of service group references.

        :type:
            list[ :class:`~str` ]
        """  # noqa: E501
        return self.__secured_group_service_references

    @secured_group_service_references.setter
    def secured_group_service_references(self, secured_group_service_references):

        self.__secured_group_service_references = secured_group_service_references

    @property
    def tcp_services(self):
        """
        

        :type:
             list[ :class:`~ntnx_microseg_py_client.models.microseg.v4.config.TcpPortRangeSpec` ]
        """  # noqa: E501
        return self.__tcp_services

    @tcp_services.setter
    def tcp_services(self, tcp_services):

        self.__tcp_services = tcp_services

    @property
    def udp_services(self):
        """
        

        :type:
             list[ :class:`~ntnx_microseg_py_client.models.microseg.v4.config.UdpPortRangeSpec` ]
        """  # noqa: E501
        return self.__udp_services

    @udp_services.setter
    def udp_services(self, udp_services):

        self.__udp_services = udp_services

    @property
    def icmp_services(self):
        """
        ICMP Type Code List.

        :type:
             list[ :class:`~ntnx_microseg_py_client.models.microseg.v4.config.IcmpTypeCodeSpec` ]
        """  # noqa: E501
        return self.__icmp_services

    @icmp_services.setter
    def icmp_services(self, icmp_services):

        self.__icmp_services = icmp_services

    @property
    def icmp_v6_services(self):
        """
        ICMPv6 Type Code List.

        :type:
             list[ :class:`~ntnx_microseg_py_client.models.microseg.v4.config.IcmpV6TypeCodeSpec` ]
        """  # noqa: E501
        return self.__icmp_v6_services

    @icmp_v6_services.setter
    def icmp_v6_services(self, icmp_v6_services):

        self.__icmp_v6_services = icmp_v6_services

    @property
    def _reserved(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_reserved

    @property
    def _object_type(self):
        """
        

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__dollar_object_type

    @property
    def _unknown_fields(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_unknown_fields

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(IntraEntityGroupRuleSpec, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        # handle unknown fields
        result['_unknown_fields'] = {}
        unknown = self.get_unknown_fields()
        if sanitize:
            unknown = self._sanitize_for_serialization(unknown)

        return {**result, **unknown}

    def _sanitize_for_serialization(self, value):
        """Recursively sanitize the value for serialization.

        :param value: The value to sanitize
        :type value: any
        :return: Sanitized value
        :rtype: any
        """
        if isinstance(value, (list, tuple)):
            return list(map(self._sanitize_for_serialization, [v for v in value if v is not None]))
        elif isinstance(value, dict):
            return {k: self._sanitize_for_serialization(v) for k, v in six.iteritems(value) if v is not None}
        elif isinstance(value, (str, int, float, bool)):
            return value
        elif isinstance(value, Path):
            return str(value)
        else:
            return value.to_dict() if hasattr(value, 'to_dict') else str(value)

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IntraEntityGroupRuleSpec):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Flow Management APIs

    Manage Network Security Policy configuration of Nutanix clusters.  # noqa: E501

    OpenAPI spec version: 4.2.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six
from pathlib import Path

from ntnx_microseg_py_client.api_client import ApiClient


class NetworkSecurityPoliciesApi(object):
    """IGNORE:
    NOTE: A placeholder for class level description
    IGNORE
    """  # noqa: E501

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()

        self.api_client = api_client
        self.__headers_to_skip = { 'authorization', 'cookie', 'host', 'user-agent' }

    def apply_network_security_policy_import(self, path, NTNX_Purge_Policies=None, _dryrun=None, **kwargs):  # noqa: E501
        """Import Network Security Policies

        >>> response = api.apply_network_security_policy_import(path, (optional) NTNX_Purge_Policies, (optional) _dryrun)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.apply_network_security_policy_import(path, async_req=True)
        >>> result = thread.get()

        :param path: 
        :type path:
            :class:`~pathlib.Path`, required
        :param NTNX_Purge_Policies: The header parameter specifies if the existing policies need to be deleted or retained upon network security policy import.
        :type NTNX_Purge_Policies:
            :class:`bool`
        :param _dryrun: A URL query parameter that allows long running operations to execute in a dry-run mode providing ability to identify trouble spots and system failures without performing the actual operation. Additionally this mode also offers a summary snapshot of the resultant system in order to better understand how things fit together. The operation runs in dry-run mode only if the provided value is true. 
        :type _dryrun:
            :class:`bool`
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_microseg_py_client.models.microseg.v4.config.CreateNetworkSecurityPolicyImportApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'path' is set
        if ('path' not in params or params['path'] is None):
            raise ValueError("Missing the required parameter `path` when calling `apply_network_security_policy_import`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_dryrun' in params and params['_dryrun'] is not None:
            query_params.append(('$dryrun', str(params['_dryrun']).lower()))  # noqa: E501

        header_params = {}
        if 'NTNX_Purge_Policies' in params and params['NTNX_Purge_Policies'] is not None:
            header_params['NTNX-Purge-Policies'] = params['NTNX_Purge_Policies']  # noqa: E501
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client._select_header_content_type(  # noqa: E501
            ['application/octet-stream'])  # noqa: E501
        if 'Content-Type' in params and params.get('Content-Type') is not None:
            header_params['Content-Type'] = params.get('Content-Type')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['path', 'NTNX_Purge_Policies', '_dryrun'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None
        if 'path' in params and params['path'] is not None:
            body_params = params['path']
            filepath = params['path']
            if not isinstance(filepath, Path) or not filepath.is_file():
                raise ValueError("The required parameter `path` is not a valid Path file when calling `apply_network_security_policy_import`")  # noqa: E501

            header_params['Content-Length'] = filepath.stat().st_size
            if 'Content-Disposition' not in header_params:
                header_params['Content-Disposition'] = 'attachment; filename="' + filepath.name + '"'

            body_params = filepath.open(mode='rb')

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/microseg/v4.2/config/policies/$actions/import', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='microseg.v4.config.CreateNetworkSecurityPolicyImportApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/microseg/v4.2/config/policies/$actions/import', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='microseg.v4.config.CreateNetworkSecurityPolicyImportApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            body_params.close()
            

    def create_network_security_policy(self, body, **kwargs):  # noqa: E501
        """Create a Network Security Policy

        >>> response = api.create_network_security_policy(body)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.create_network_security_policy(body, async_req=True)
        >>> result = thread.get()

        :param body: 
        :type body:
            :class:`~ntnx_microseg_py_client.models.microseg.v4.config.NetworkSecurityPolicy`, required
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_microseg_py_client.models.microseg.v4.config.CreateNetworkSecurityPolicyApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'body' is set
        if ('body' not in params or params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_network_security_policy`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client._select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501
        if 'Content-Type' in params and params.get('Content-Type') is not None:
            header_params['Content-Type'] = params.get('Content-Type')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['body'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None
        if 'body' in params and params['body'] is not None:
            body_params = params['body']

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/microseg/v4.2/config/policies', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='microseg.v4.config.CreateNetworkSecurityPolicyApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/microseg/v4.2/config/policies', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='microseg.v4.config.CreateNetworkSecurityPolicyApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            pass

    def delete_network_security_policy_by_id(self, extId, **kwargs):  # noqa: E501
        """Delete a Network Security Policy by ExtID

        >>> response = api.delete_network_security_policy_by_id(extId)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.delete_network_security_policy_by_id(extId, async_req=True)
        >>> result = thread.get()

        :param extId: Network security policy UUID.
        :type extId:
            :class:`str`, required
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_microseg_py_client.models.microseg.v4.config.DeleteNetworkSecurityPolicyApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'extId' is set
        if ('extId' not in params or params['extId'] is None):
            raise ValueError("Missing the required parameter `extId` when calling `delete_network_security_policy_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'extId' in params and params['extId'] is not None:
            path_params['extId'] = params['extId']  # noqa: E501

        query_params = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['extId'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/microseg/v4.2/config/policies/{extId}', 'DELETE',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='microseg.v4.config.DeleteNetworkSecurityPolicyApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/microseg/v4.2/config/policies/{extId}', 'DELETE',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='microseg.v4.config.DeleteNetworkSecurityPolicyApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            pass

    def export_network_security_policy(self, body=None, **kwargs):  # noqa: E501
        """Export Network Security Policies

        >>> response = api.export_network_security_policy((optional) body)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.export_network_security_policy(async_req=True)
        >>> result = thread.get()

        :param body: A list of network security policy external identifiers to export.
        :type body:
            :class:`~ntnx_microseg_py_client.models.microseg.v4.config.NetworkSecurityPolicyExportSpec`
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_microseg_py_client.models.microseg.v4.config.CreateNetworkSecurityPolicyExportApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client._select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501
        if 'Content-Type' in params and params.get('Content-Type') is not None:
            header_params['Content-Type'] = params.get('Content-Type')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['body'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None
        if 'body' in params and params['body'] is not None:
            body_params = params['body']

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/microseg/v4.2/config/policies/$actions/prepare-export', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='microseg.v4.config.CreateNetworkSecurityPolicyExportApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/microseg/v4.2/config/policies/$actions/prepare-export', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='microseg.v4.config.CreateNetworkSecurityPolicyExportApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            pass

    def get_network_security_policy_by_id(self, extId, **kwargs):  # noqa: E501
        """Get a Network Security Policy by ExtID

        >>> response = api.get_network_security_policy_by_id(extId)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.get_network_security_policy_by_id(extId, async_req=True)
        >>> result = thread.get()

        :param extId: Network security policy UUID.
        :type extId:
            :class:`str`, required
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_microseg_py_client.models.microseg.v4.config.GetNetworkSecurityPolicyApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'extId' is set
        if ('extId' not in params or params['extId'] is None):
            raise ValueError("Missing the required parameter `extId` when calling `get_network_security_policy_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'extId' in params and params['extId'] is not None:
            path_params['extId'] = params['extId']  # noqa: E501

        query_params = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['extId'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/microseg/v4.2/config/policies/{extId}', 'GET',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='microseg.v4.config.GetNetworkSecurityPolicyApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/microseg/v4.2/config/policies/{extId}', 'GET',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='microseg.v4.config.GetNetworkSecurityPolicyApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            pass

    def list_network_security_policies(self, _page=None, _limit=None, _filter=None, _orderby=None, _select=None, **kwargs):  # noqa: E501
        """List all the Network Security Policies

        >>> response = api.list_network_security_policies((optional) _page, (optional) _limit, (optional) _filter, (optional) _orderby, (optional) _select)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.list_network_security_policies(async_req=True)
        >>> result = thread.get()

        :param _page: A URL query parameter that specifies the page number of the result set. It must be a positive integer between 0 and the maximum number of pages that are available for that resource. Any number out of this range might lead to no results. 
        :type _page:
            :class:`int`
        :param _limit: A URL query parameter that specifies the total number of records returned in the result set.  Must be a positive integer between 1 and 100. Any number out of this range will lead to a validation error. If the limit is not provided, a default value of 50 records will be returned in the result set. 
        :type _limit:
            :class:`int`
        :param _filter: A URL query parameter that allows clients to filter a collection of resources. The expression specified with $filter is evaluated for each resource in the collection, and only items where the expression evaluates to true are included in the response. Expression specified with the $filter must conform to the [OData V4.01](https://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html) URL conventions. For example, filter '$filter=name eq 'karbon-ntnx-1.0' would filter the result on cluster name 'karbon-ntnx1.0', filter '$filter=startswith(name, 'C')' would filter on cluster name starting with 'C'.
        :type _filter:
            :class:`str`
        :param _orderby: A URL query parameter that allows clients to specify the sort criteria for the returned list of objects. Resources can be sorted in ascending order using asc or descending order using desc. If asc or desc are not specified, the resources will be sorted in ascending order by default. For example, '$orderby=templateName desc' would get all templates sorted by templateName in descending order.
        :type _orderby:
            :class:`str`
        :param _select: A URL query parameter that allows clients to request a specific set of properties for each entity or complex type. Expression specified with the $select must conform to the [OData V4.01](https://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html) URL conventions. If a $select expression consists of a single select item that is an asterisk (i.e., *), then all properties on the matching resource will be returned.
        :type _select:
            :class:`str`
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_microseg_py_client.models.microseg.v4.config.ListNetworkSecurityPoliciesApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']


        collection_formats = {}

        path_params = {}

        query_params = []
        if '_page' in params and params['_page'] is not None:
            query_params.append(('$page', params['_page']))  # noqa: E501
        if '_limit' in params and params['_limit'] is not None:
            query_params.append(('$limit', params['_limit']))  # noqa: E501
        if '_filter' in params and params['_filter'] is not None:
            query_params.append(('$filter', params['_filter']))  # noqa: E501
        if '_orderby' in params and params['_orderby'] is not None:
            query_params.append(('$orderby', params['_orderby']))  # noqa: E501
        if '_select' in params and params['_select'] is not None:
            query_params.append(('$select', params['_select']))  # noqa: E501

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json', 'application/octet-stream'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['_page', '_limit', '_filter', '_orderby', '_select'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/microseg/v4.2/config/policies', 'GET',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='microseg.v4.config.ListNetworkSecurityPoliciesApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/microseg/v4.2/config/policies', 'GET',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='microseg.v4.config.ListNetworkSecurityPoliciesApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            pass

    def list_network_security_policy_rules(self, policyExtId, _page=None, _limit=None, _filter=None, _orderby=None, _select=None, **kwargs):  # noqa: E501
        """List all the Network Security Policy rules by policy ExtID

        >>> response = api.list_network_security_policy_rules(policyExtId, (optional) _page, (optional) _limit, (optional) _filter, (optional) _orderby, (optional) _select)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.list_network_security_policy_rules(policyExtId, async_req=True)
        >>> result = thread.get()

        :param policyExtId: Network security policy UUID.
        :type policyExtId:
            :class:`str`, required
        :param _page: A URL query parameter that specifies the page number of the result set. It must be a positive integer between 0 and the maximum number of pages that are available for that resource. Any number out of this range might lead to no results. 
        :type _page:
            :class:`int`
        :param _limit: A URL query parameter that specifies the total number of records returned in the result set.  Must be a positive integer between 1 and 100. Any number out of this range will lead to a validation error. If the limit is not provided, a default value of 50 records will be returned in the result set. 
        :type _limit:
            :class:`int`
        :param _filter: A URL query parameter that allows clients to filter a collection of resources. The expression specified with $filter is evaluated for each resource in the collection, and only items where the expression evaluates to true are included in the response. Expression specified with the $filter must conform to the [OData V4.01](https://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html) URL conventions. For example, filter '$filter=name eq 'karbon-ntnx-1.0' would filter the result on cluster name 'karbon-ntnx1.0', filter '$filter=startswith(name, 'C')' would filter on cluster name starting with 'C'.
        :type _filter:
            :class:`str`
        :param _orderby: A URL query parameter that allows clients to specify the sort criteria for the returned list of objects. Resources can be sorted in ascending order using asc or descending order using desc. If asc or desc are not specified, the resources will be sorted in ascending order by default. For example, '$orderby=templateName desc' would get all templates sorted by templateName in descending order.
        :type _orderby:
            :class:`str`
        :param _select: A URL query parameter that allows clients to request a specific set of properties for each entity or complex type. Expression specified with the $select must conform to the [OData V4.01](https://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html) URL conventions. If a $select expression consists of a single select item that is an asterisk (i.e., *), then all properties on the matching resource will be returned.
        :type _select:
            :class:`str`
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_microseg_py_client.models.microseg.v4.config.ListNetworkSecurityPolicyRulesApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'policyExtId' is set
        if ('policyExtId' not in params or params['policyExtId'] is None):
            raise ValueError("Missing the required parameter `policyExtId` when calling `list_network_security_policy_rules`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'policyExtId' in params and params['policyExtId'] is not None:
            path_params['policyExtId'] = params['policyExtId']  # noqa: E501

        query_params = []
        if '_page' in params and params['_page'] is not None:
            query_params.append(('$page', params['_page']))  # noqa: E501
        if '_limit' in params and params['_limit'] is not None:
            query_params.append(('$limit', params['_limit']))  # noqa: E501
        if '_filter' in params and params['_filter'] is not None:
            query_params.append(('$filter', params['_filter']))  # noqa: E501
        if '_orderby' in params and params['_orderby'] is not None:
            query_params.append(('$orderby', params['_orderby']))  # noqa: E501
        if '_select' in params and params['_select'] is not None:
            query_params.append(('$select', params['_select']))  # noqa: E501

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['policyExtId', '_page', '_limit', '_filter', '_orderby', '_select'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/microseg/v4.2/config/policies/{policyExtId}/rules', 'GET',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='microseg.v4.config.ListNetworkSecurityPolicyRulesApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/microseg/v4.2/config/policies/{policyExtId}/rules', 'GET',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='microseg.v4.config.ListNetworkSecurityPolicyRulesApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            pass

    def update_network_security_policy_by_id(self, extId, body, **kwargs):  # noqa: E501
        """Update a Network Security Policy by ExtID

        >>> response = api.update_network_security_policy_by_id(extId, body)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.update_network_security_policy_by_id(extId, body, async_req=True)
        >>> result = thread.get()

        :param extId: Network security policy UUID.
        :type extId:
            :class:`str`, required
        :param body: Updates the Network Security Policy with the provided ExtID.
        :type body:
            :class:`~ntnx_microseg_py_client.models.microseg.v4.config.NetworkSecurityPolicy`, required
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_microseg_py_client.models.microseg.v4.config.UpdateNetworkSecurityPolicyApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'extId' is set
        if ('extId' not in params or params['extId'] is None):
            raise ValueError("Missing the required parameter `extId` when calling `update_network_security_policy_by_id`")  # noqa: E501
        # verify the required parameter 'body' is set
        if ('body' not in params or params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_network_security_policy_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'extId' in params and params['extId'] is not None:
            path_params['extId'] = params['extId']  # noqa: E501

        query_params = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client._select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501
        if 'Content-Type' in params and params.get('Content-Type') is not None:
            header_params['Content-Type'] = params.get('Content-Type')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['extId', 'body'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None
        if 'body' in params and params['body'] is not None:
            body_params = params['body']

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/microseg/v4.2/config/policies/{extId}', 'PUT',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='microseg.v4.config.UpdateNetworkSecurityPolicyApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/microseg/v4.2/config/policies/{extId}', 'PUT',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='microseg.v4.config.UpdateNetworkSecurityPolicyApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            pass




from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from ntnx_microseg_py_client.api.address_groups_api import AddressGroupsApi
from ntnx_microseg_py_client.api.directory_server_configs_api import DirectoryServerConfigsApi
from ntnx_microseg_py_client.api.entity_groups_api import EntityGroupsApi
from ntnx_microseg_py_client.api.network_security_policies_api import NetworkSecurityPoliciesApi
from ntnx_microseg_py_client.api.service_groups_api import ServiceGroupsApi



# coding: utf-8


"""
IGNORE:
    Nutanix Flow Management APIs

    Manage Network Security Policy configuration of Nutanix clusters.  # noqa: E501

    OpenAPI spec version: 4.2.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
from ntnx_microseg_py_client.models.common.v1.config.Message import Message  # noqa: F401,E501
from ntnx_microseg_py_client.models.common.v1.response.ApiLink import ApiLink  # noqa: F401,E501
from ntnx_microseg_py_client.models.common.v1.response.ExternalizableAbstractModel import ExternalizableAbstractModel  # noqa: F401,E501
from ntnx_microseg_py_client.models.microseg.v4.operation.PolicyUpgradeSummary import PolicyUpgradeSummary  # noqa: F401,E501
from ntnx_microseg_py_client.models.microseg.v4.operation.SubnetUpgradeSummary import SubnetUpgradeSummary  # noqa: F401,E501
from ntnx_microseg_py_client.models.microseg.v4.operation.TotalPolicyCount import TotalPolicyCount  # noqa: F401,E501

class DryRunSummary(ExternalizableAbstractModel):

    """

    :param policy_summaries: (:attr:`policy_summaries`) 
    :type policy_summaries: 
    
    
    :param count_summary: (:attr:`count_summary`) 
    :type count_summary: 
    
    
    :param subnet_summaries: (:attr:`subnet_summaries`) 
    :type subnet_summaries: 
    
    
    :param summary_failures: (:attr:`summary_failures`) Summary of failures from the flow upgrade dry-run summary report.
    :type summary_failures: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'policy_summaries': 'list[microseg.v4.operation.PolicyUpgradeSummary]',
        'count_summary': 'microseg.v4.operation.TotalPolicyCount',
        'subnet_summaries': 'list[microseg.v4.operation.SubnetUpgradeSummary]',
        'summary_failures': 'list[common.v1.config.Message]',
        'ext_id': 'str',
        'links': 'list[common.v1.response.ApiLink]',
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'policy_summaries': 'policySummaries',
        'count_summary': 'countSummary',
        'subnet_summaries': 'subnetSummaries',
        'summary_failures': 'summaryFailures',
        'ext_id': 'extId',
        'links': 'links',
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, policy_summaries=None, count_summary=None, subnet_summaries=None, summary_failures=None, ext_id=None, links=None, tenant_id=None, *args, **kwargs):  # noqa: E501
        ExternalizableAbstractModel.__init__(self, ext_id, links, tenant_id, *args, **kwargs)
        self.__policy_summaries = None
        self.__count_summary = None
        self.__subnet_summaries = None
        self.__summary_failures = None
        self.discriminator = None
        if policy_summaries is not None:
            self.__policy_summaries = policy_summaries
        if count_summary is not None:
            self.__count_summary = count_summary
        if subnet_summaries is not None:
            self.__subnet_summaries = subnet_summaries
        if summary_failures is not None:
            self.__summary_failures = summary_failures

    def _initialize_object_type(self):
        return 'microseg.v4.operation.DryRunSummary'

    def _initialize_object_version(self):
        return 'v4.r2'


    @property
    def policy_summaries(self):
        """
        

        :type:
             list[ :class:`~ntnx_microseg_py_client.models.microseg.v4.operation.PolicyUpgradeSummary` ]
        """  # noqa: E501
        return self.__policy_summaries

    @policy_summaries.setter
    def policy_summaries(self, policy_summaries):

        self.__policy_summaries = policy_summaries

    @property
    def count_summary(self):
        """
        

        :type:
            :class:`~ntnx_microseg_py_client.models.microseg.v4.operation.TotalPolicyCount`
        """  # noqa: E501
        return self.__count_summary

    @count_summary.setter
    def count_summary(self, count_summary):

        self.__count_summary = count_summary

    @property
    def subnet_summaries(self):
        """
        

        :type:
             list[ :class:`~ntnx_microseg_py_client.models.microseg.v4.operation.SubnetUpgradeSummary` ]
        """  # noqa: E501
        return self.__subnet_summaries

    @subnet_summaries.setter
    def subnet_summaries(self, subnet_summaries):

        self.__subnet_summaries = subnet_summaries

    @property
    def summary_failures(self):
        """
        Summary of failures from the flow upgrade dry-run summary report.

        :type:
             list[ :class:`~ntnx_microseg_py_client.models.common.v1.config.Message` ]
        """  # noqa: E501
        return self.__summary_failures

    @summary_failures.setter
    def summary_failures(self, summary_failures):

        self.__summary_failures = summary_failures

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(DryRunSummary, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        # handle unknown fields
        result['_unknown_fields'] = {}
        unknown = self.get_unknown_fields()
        if sanitize:
            unknown = self._sanitize_for_serialization(unknown)

        return {**result, **unknown}


    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DryRunSummary):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Flow Management APIs

    Manage Network Security Policy configuration of Nutanix clusters.  # noqa: E501

    OpenAPI spec version: 4.2.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path

class TenantAwareModel(object):

    """A model base class whose instances are bound to a specific tenant.  This model adds a tenantId to the base model class that it extends and is automatically set by the server. 

    :param tenant_id: (:attr:`tenant_id`) A globally unique identifier that represents the tenant that owns this entity. The system automatically assigns it, and it and is immutable from an API consumer perspective (some use cases may cause this ID to change - For instance, a use case may require the transfer of ownership of the entity, but these cases are handled automatically on the server). 
    :type tenant_id: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, tenant_id=None, *args, **kwargs):  # noqa: E501
        self.__tenant_id = None
        self.discriminator = None
        if tenant_id is not None:
            self.__tenant_id = tenant_id
        # populate hidden vars if not empty
        self._populate_hidden_vars(kwargs)

    def _initialize_object_type(self):
        return 'common.v1.config.TenantAwareModel'

    def _initialize_object_version(self):
        return 'v1.r0'

    def _populate_hidden_vars(self, kwargs):
        if "_reserved" in kwargs and kwargs["_reserved"] is not None:
            self.__dollar_reserved = kwargs["_reserved"]
        elif hasattr(self, "attribute_map") and "_reserved" in self.attribute_map and self.attribute_map["_reserved"] in kwargs and kwargs[self.attribute_map["_reserved"]] is not None:
            self.__dollar_reserved = kwargs[self.attribute_map["_reserved"]]
        else :
            self.__dollar_reserved = {"$fv": self._initialize_object_version()}
        if "_unknown_fields" in kwargs and kwargs["_unknown_fields"] is not None:
            self.__dollar_unknown_fields = kwargs["_unknown_fields"]
        elif hasattr(self, "attribute_map") and "_unknown_fields" in self.attribute_map and self.attribute_map["_unknown_fields"] in kwargs and kwargs[self.attribute_map["_unknown_fields"]] is not None:
            self.__dollar_unknown_fields = kwargs[self.attribute_map["_unknown_fields"]]
        else :
            self.__dollar_unknown_fields = {}
        if "_object_type" in kwargs and kwargs["_object_type"] is not None:
            self.__dollar_object_type = kwargs["_object_type"]
        elif hasattr(self, "attribute_map") and "_object_type" in self.attribute_map and self.attribute_map["_object_type"] in kwargs and kwargs[self.attribute_map["_object_type"]] is not None:
            self.__dollar_object_type = kwargs[self.attribute_map["_object_type"]]
        else:
            self.__dollar_object_type = self._initialize_object_type()

    def get_object_type(self):
        return self.__dollar_object_type

    def get_reserved(self):
        return self.__dollar_reserved

    def get_unknown_fields(self):
        return self.__dollar_unknown_fields

    @property
    def tenant_id(self):
        """
        A globally unique identifier that represents the tenant that owns this entity. The system automatically assigns it, and it and is immutable from an API consumer perspective (some use cases may cause this ID to change - For instance, a use case may require the transfer of ownership of the entity, but these cases are handled automatically on the server). 

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        if tenant_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', tenant_id):  # noqa: E501
            raise ValueError(r"Invalid value for `tenant_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__tenant_id = tenant_id

    @property
    def _reserved(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_reserved

    @property
    def _object_type(self):
        """
        

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__dollar_object_type

    @property
    def _unknown_fields(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_unknown_fields

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(TenantAwareModel, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        # handle unknown fields
        result['_unknown_fields'] = {}
        unknown = self.get_unknown_fields()
        if sanitize:
            unknown = self._sanitize_for_serialization(unknown)

        return {**result, **unknown}

    def _sanitize_for_serialization(self, value):
        """Recursively sanitize the value for serialization.

        :param value: The value to sanitize
        :type value: any
        :return: Sanitized value
        :rtype: any
        """
        if isinstance(value, (list, tuple)):
            return list(map(self._sanitize_for_serialization, [v for v in value if v is not None]))
        elif isinstance(value, dict):
            return {k: self._sanitize_for_serialization(v) for k, v in six.iteritems(value) if v is not None}
        elif isinstance(value, (str, int, float, bool)):
            return value
        elif isinstance(value, Path):
            return str(value)
        else:
            return value.to_dict() if hasattr(value, 'to_dict') else str(value)

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TenantAwareModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Flow Management APIs

    Manage Network Security Policy configuration of Nutanix clusters.  # noqa: E501

    OpenAPI spec version: 4.2.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path

class ErrorResponseerror(object):

    """


    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
    }

    attribute_map = {
    }

    discriminator_value_class_map = {
        'EMPTY_LIST': 'list[str]',
        'EMPTY_MAP': 'dict(str, object)',
        'List<microseg.v4.error.AppMessage>': 'list[microseg.v4.error.AppMessage]',
        'microseg.v4.error.SchemaValidationError': 'microseg.v4.error.SchemaValidationError'
    }

    ONE_OF_ITEM_DISCRIMINATOR_NAME = '$errorItemDiscriminator'


    def __init__(self, *args, **kwargs):  # noqa: E501
        self.discriminator = None
        # populate hidden vars if not empty
        self._populate_hidden_vars(kwargs)

    def _initialize_object_type(self):
        return 'OneOfmicroseg.v4.error.ErrorResponseerror'

    def _initialize_object_version(self):
        return ''

    def _populate_hidden_vars(self, kwargs):
        if "_reserved" in kwargs and kwargs["_reserved"] is not None:
            self.__dollar_reserved = kwargs["_reserved"]
        elif hasattr(self, "attribute_map") and "_reserved" in self.attribute_map and self.attribute_map["_reserved"] in kwargs and kwargs[self.attribute_map["_reserved"]] is not None:
            self.__dollar_reserved = kwargs[self.attribute_map["_reserved"]]
        else :
            self.__dollar_reserved = {"$fv": self._initialize_object_version()}
        if "_unknown_fields" in kwargs and kwargs["_unknown_fields"] is not None:
            self.__dollar_unknown_fields = kwargs["_unknown_fields"]
        elif hasattr(self, "attribute_map") and "_unknown_fields" in self.attribute_map and self.attribute_map["_unknown_fields"] in kwargs and kwargs[self.attribute_map["_unknown_fields"]] is not None:
            self.__dollar_unknown_fields = kwargs[self.attribute_map["_unknown_fields"]]
        else :
            self.__dollar_unknown_fields = {}
        if "_object_type" in kwargs and kwargs["_object_type"] is not None:
            self.__dollar_object_type = kwargs["_object_type"]
        elif hasattr(self, "attribute_map") and "_object_type" in self.attribute_map and self.attribute_map["_object_type"] in kwargs and kwargs[self.attribute_map["_object_type"]] is not None:
            self.__dollar_object_type = kwargs[self.attribute_map["_object_type"]]
        else:
            self.__dollar_object_type = self._initialize_object_type()

    def get_object_type(self):
        return self.__dollar_object_type

    def get_reserved(self):
        return self.__dollar_reserved

    def get_unknown_fields(self):
        return self.__dollar_unknown_fields

    def get_real_child_model(self, discriminator):
        """Returns the real base class specified by the discriminator"""
        if discriminator is not None and discriminator in self.discriminator_value_class_map:
            return self.discriminator_value_class_map.get(discriminator)
        return None

    @staticmethod
    def get_discriminator_from_object(value):
        """Returns the discriminator for the provided object.
        """
        if not value:
            disc = 'list[str]'
        elif hasattr(value, "_object_type"):
            disc = value.get_object_type()
        elif type(value) == list:
            if hasattr(value[0], "_object_type"):
                datatype = value[0].get_object_type()
            else:
                datatype = type(value[0]).__name__
            disc = 'list[' + datatype + ']'
        elif type(value) == dict:
            if hasattr(next(iter(value.values())), "_object_type"):
                datatype = next(iter(value.values())).get_object_type()
            else:
                datatype = type(next(iter(value.values()))).__name__
            disc = 'dict(str, ' + datatype + ')'
        else:
            disc = type(value).__name__
        if disc in ErrorResponseerror.discriminator_value_class_map.values():
            return list(ErrorResponseerror.discriminator_value_class_map.keys())[list(ErrorResponseerror.discriminator_value_class_map.values()).index(disc)]
        return None


    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(ErrorResponseerror, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        # handle unknown fields
        result['_unknown_fields'] = {}
        unknown = self.get_unknown_fields()
        if sanitize:
            unknown = self._sanitize_for_serialization(unknown)

        return {**result, **unknown}

    def _sanitize_for_serialization(self, value):
        """Recursively sanitize the value for serialization.

        :param value: The value to sanitize
        :type value: any
        :return: Sanitized value
        :rtype: any
        """
        if isinstance(value, (list, tuple)):
            return list(map(self._sanitize_for_serialization, [v for v in value if v is not None]))
        elif isinstance(value, dict):
            return {k: self._sanitize_for_serialization(v) for k, v in six.iteritems(value) if v is not None}
        elif isinstance(value, (str, int, float, bool)):
            return value
        elif isinstance(value, Path):
            return str(value)
        else:
            return value.to_dict() if hasattr(value, 'to_dict') else str(value)

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ErrorResponseerror):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

